@@ -150,7 +150,19 @@ extern Datum ExecFetchSlotTupleDatum(TupleTableSlot *slot);
 	reindex_index((indexId))
 #define func_signature_string(funcname, nargs, argnames, argtypes) \
 	func_signature_string((funcname), (nargs), (argtypes))
-#define GetConfigOption(name, restrict_superuser)	GetConfigOption((name))
+
+#endif
+
+#if PG_VERSION_NUM < 90200
+
+#define RangeVarGetRelid(relation, lockmode, missing_ok, nowait) \
+	RangeVarGetRelid((relation), (missing_ok))
+
+#endif
+
+#if PG_VERSION_NUM < 90100
+
+#define PG_GET_COLLATION()		(InvalidOid)
 
 #endif
 
@@ -170,4 +182,12 @@ extern Datum ExecFetchSlotTupleDatum(TupleTableSlot *slot);
 	FuncnameGetCandidates((names), (nargs), (variadic), (defaults))
 #endif
 
+#if PG_VERSION_NUM < 90000
+#define GetConfigOption(name, missing_ok, restrict_superuser) \
+	GetConfigOption((name))
+#elif PG_VERSION_NUM < 90100
+#define GetConfigOption(name, missing_ok, restrict_superuser) \
+	GetConfigOption((name), (restrict_superuser))
+#endif
+
 #endif   /* PGUT_BE_H */
